[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / SignatureProof

# Interface: SignatureProof

Interface for signature-based ownership proofs that use cryptographic message signing

## Remarks

Extends the base OwnershipProface to add signature-specific properties:
- Supports multiple signature standards like EIP-191, EIP-712, BIP-137, SIWE
- Includes the cryptographic proof signature string
- Contains an attestation message that was signed
- Records which wallet provider was used for signing

The signature proves ownership by demonstrating control of the private keys
associated with the claimed address.

## See

 - [ProofTypes](../enumerations/ProofTypes.md) For supported signature types
 - [OwnershipProof](OwnershipProof.md) For base proof properties

## Extends

- [`OwnershipProof`](OwnershipProof.md)

## Properties

### address

> **address**: \`$\{string\}:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`address`](OwnershipProof.md#address)

#### Defined in

[types.ts:1134](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1134)

***

### attestation

> **attestation**: `string`

#### Defined in

[types.ts:1171](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1171)

***

### chainSpecificData?

> `optional` **chainSpecificData**: `object`

#### cardanoCoseKey?

> `optional` **cardanoCoseKey**: `string`

#### Defined in

[types.ts:1174](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1174)

***

### did

> **did**: \`did:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`did`](OwnershipProof.md#did)

#### Defined in

[types.ts:1133](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1133)

***

### proof

> **proof**: `string`

#### Defined in

[types.ts:1170](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1170)

***

### status

> **status**: [`ProofStatus`](../enumerations/ProofStatus.md)

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`status`](OwnershipProof.md#status)

#### Defined in

[types.ts:1132](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1132)

***

### type

> **type**: [`SIWE`](../enumerations/ProofTypes.md#siwe) \| [`SIWX`](../enumerations/ProofTypes.md#siwx) \| [`EIP191`](../enumerations/ProofTypes.md#eip191) \| [`EIP712`](../enumerations/ProofTypes.md#eip712) \| [`EIP1271`](../enumerations/ProofTypes.md#eip1271) \| [`BIP137`](../enumerations/ProofTypes.md#bip137) \| [`BIP322`](../enumerations/ProofTypes.md#bip322) \| [`BIP137_XPUB`](../enumerations/ProofTypes.md#bip137_xpub) \| [`TIP191`](../enumerations/ProofTypes.md#tip191) \| [`ED25519`](../enumerations/ProofTypes.md#ed25519) \| [`XRP_ED25519`](../enumerations/ProofTypes.md#xrp_ed25519) \| [`XLM_ED25519`](../enumerations/ProofTypes.md#xlm_ed25519) \| [`CIP8`](../enumerations/ProofTypes.md#cip8)

#### Overrides

[`OwnershipProof`](OwnershipProof.md).[`type`](OwnershipProof.md#type)

#### Defined in

[types.ts:1155](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1155)

***

### wallet\_provider

> **wallet\_provider**: `string`

#### Defined in

[types.ts:1172](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1172)

***

### xpub?

> `optional` **xpub**: `string`

#### Defined in

[types.ts:1173](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/f6a0825d098b61a3bc31d6c197072643eb78a452/src/types.ts#L1173)
